@@ -1,4 +1,4 @@
-(* $Id: telnet_client.ml 126 2004-05-25 20:56:41Z gerd $
+(* $Id: telnet_client.ml 142 2005-07-26 21:59:31Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -116,9 +116,6 @@ type telnet_option_state =
 ;;
 
 
-module Aux = Http_client_aux
-
-
 let rec syscall f =  (* TODO: move to Aux *)
   (* Invoke system call, and handle EINTR *)
   try
@@ -514,9 +511,9 @@ class telnet_session =
     method private inet_addr hostname =
       try
 	(* TODO: 'inet_addr_of_string' may block *)
-	syscall (fun () -> Unix.inet_addr_of_string (Aux.match_ip hostname))
+	syscall (fun () -> Unix.inet_addr_of_string hostname)
       with
-	  Not_found ->
+	  Failure _ ->
 	    try
 	      let h = syscall (fun () -> Unix.gethostbyname hostname) in
 	      h.Unix.h_addr_list.(0)
