@@ -28,6 +28,8 @@ request () {
 	strace ./test_client -verbose -port "$server_port" "$@" 2>client.out
     elif [ -n "$DEBUGGED_CLIENT" ]; then
 	ocamldebug -I .. ./test_client -verbose -port "$server_port" "$@"
+    elif [ -n "$GDB_CLIENT" ]; then
+	gdb --args ./run ./test_client -verbose -port "$server_port" "$@"
     else
 	./test_client -verbose -port "$server_port" "$@" 2>client.out
     fi
