@@ -2,9 +2,9 @@
 
 start_test_server \
   -line 1 -file data/require-basicauth \
-  -line 8 -expect "authorization: Basic dGVzdHVzZXI6dGVzdHBhc3N3b3Jk
+  -line 9 -expect "Authorization: Basic dGVzdHVzZXI6dGVzdHBhc3N3b3Jk
 " \
-  -line 9 -file data/framed
+  -line 11 -file data/framed
 trap "stop_test_server" EXIT
 request \
   -realm testrealm -user testuser -password testpassword -basic-auth \
