@@ -7,7 +7,7 @@ start_test_server \
   -line 9 -file data/require-basicauth \
   -line 13 -expect "proxy-authorization: Basic dGVzdHVzZXI6dGVzdHBhc3N3b3Jk
 " \
-  -line 14 -expect "authorization: Basic dGVzdHVzZXI6dGVzdHBhc3N3b3Jk
+  -line 14 -expect "Authorization: Basic dGVzdHVzZXI6dGVzdHBhc3N3b3Jk
 " \
   -line 15 -file data/framed
 trap "stop_test_server" EXIT
